==> haskell-tree-diff-0.0.2.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.2.1
id: tree-diff-0.0.2.1-30z2QoR5awtC49jjVpf0Qy
key: tree-diff-0.0.2.1-30z2QoR5awtC49jjVpf0Qy
license: BSD-3-Clause
copyright: (c) 2017-2018 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data, Testing
abi: 13e6d84c5ebb1086f2bef4ba58d52a5f
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.6.5/site-local/tree-diff-0.0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tree-diff-0.0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tree-diff-0.0.2.1
hs-libraries: HStree-diff-0.0.2.1-30z2QoR5awtC49jjVpf0Qy
depends:
    MemoTrie-0.6.9-HWBZ1Ykm7kbEs62OF2Qxfp
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq
    ansi-wl-pprint-0.6.8.2-Bo6ysK7CsNLHN6Mrx4aKYi base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 generics-sop-0.5.0.0-KcRCSh2JEyL6JzNJdcWr49
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo parsec-3.1.13.0
    parsers-0.12.10-ILAIFpn5o9X9YgFPnkWytu pretty-1.1.3.6
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.0.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.2
id: tree-diff-0.0.2-LHngIsn3WOLDyoyn0j8jhP
key: tree-diff-0.0.2-LHngIsn3WOLDyoyn0j8jhP
license: BSD-3-Clause
copyright: (c) 2017-2018 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data, Testing
abi: 12ec29caca59317c7965150f2647ad69
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.6.3/site-local/tree-diff-0.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/tree-diff-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tree-diff-0.0.2
hs-libraries: HStree-diff-0.0.2-LHngIsn3WOLDyoyn0j8jhP
depends:
    MemoTrie-0.6.9-Ew65K6Qub28LOqPLBPfBX9
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc
    aeson-1.4.2.0-g6WW26hc5QFrgotIu9IXt
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 generics-sop-0.3.2.0-1LIoMWx8QIZINcf2OfoAby
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo parsec-3.1.13.0
    parsers-0.12.9-2RdT503293zENIVca4R4OP pretty-1.1.3.6
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
